window.Gleam.initSearch([{"doc":"ftpasta","title":"ftpasta","content":"# FTPasta\n\n[![Package Version](https://img.shields.io/hexpm/v/ftpasta)](https://hex.pm/packages/ftpasta)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/ftpasta/)\n\nA simple wrapper around Erlang&#39;s built-in `ftp` module.\nThis library is a work-in-progress, and should not be relied on in its current state.\n\n## Example Usage\n\n```sh\ngleam add ftpasta\n```\n```gleam\nimport ftpasta\nimport ftpasta/tls_config\nimport gleam/io\nimport gleam/list\n\npub fn main() {\n  // Connect to a server.\n  let assert Ok(connection) =\n    ftpasta.new(&quot;ftp.gnu.org&quot;)\n    |&gt; ftpasta.encryption(tls_config.Plaintext)\n    |&gt; ftpasta.connect()\n\n  // List the files.\n  let assert Ok(items) = ftpasta.list(connection, &quot;&quot;)\n  list.map(items, fn(item) { io.println(item.name) })\n\n  // Close the connection.\n  ftpasta.close(connection)\n}\n```\n\n## Development\n\nThe included script `run_tests.sh` will start two instances of `vsftpd` with the required configuration, run all tests, and then shut the servers down.\n```sh\n./run_tests.sh\n```\n","url":"index.html"},{"doc":"ftpasta/ftp_error","title":"FTPError","content":"pub type FTPError {\n  Echunk\n  Eclosed\n  Econn\n  Ehost\n  Elogin\n  Enotbinary\n  Epath\n  Etype\n  Euser\n  Etnospc\n  Epnospc\n  Efnamena\n  DirParseError\n  LocalFileError(simplifile.FileError)\n}\n Error type returned by FTP functions.\nEchunk\n\n\nEclosed\n\n\nEconn\n\n\nEhost\n\n\nElogin\n\n\nEnotbinary\n\n\nEpath\n\n\nEtype\n\n\nEuser\n\n\nEtnospc\n\n\nEpnospc\n\n\nEfnamena\n\n\nDirParseError\n Error when paring the output of &quot;ls&quot;.\n\nLocalFileError(simplifile.FileError)\n Error from working with files locally.\n\nSynonyms:\nftpasta/ftp_error.FTPError\nftpasta/ftp_error FTPError","url":"ftpasta/ftp_error.html#FTPError"},{"doc":"ftpasta/ftp_error","title":"ftpasta/ftp_error","content":"","url":"ftpasta/ftp_error.html"},{"doc":"ftpasta/tls_config","title":"TLSConfig","content":"pub type TLSConfig {\n  Explicit\n  Implicit\n  Plaintext\n}\n\nExplicit\n\n\nImplicit\n\n\nPlaintext\n\n\nSynonyms:\nftpasta/tls_config.TLSConfig\nftpasta/tls_config TLSConfig","url":"ftpasta/tls_config.html#TLSConfig"},{"doc":"ftpasta/tls_config","title":"ftpasta/tls_config","content":"","url":"ftpasta/tls_config.html"},{"doc":"ftpasta","title":"Config","content":"pub type Config {\n  Config(\n    host: String,\n    port: Int,\n    tls: TLSConfig,\n    username: String,\n    password: String,\n  )\n}\n Configuration struct for building FTP connections.\nConfig(\n  host: String,\n  port: Int,\n  tls: TLSConfig,\n  username: String,\n  password: String,\n)\n\n\nSynonyms:\nftpasta.Config\nftpasta Config","url":"ftpasta.html#Config"},{"doc":"ftpasta","title":"Connection","content":"pub opaque type Connection\n Type representing an FTP connection.\n\nSynonyms:\nftpasta.Connection\nftpasta Connection","url":"ftpasta.html#Connection"},{"doc":"ftpasta","title":"Listing","content":"pub type Listing {\n  Directory(name: String)\n  File(name: String, size: Int)\n  Link(name: String, target: String)\n}\n Remote file type.\nDirectory(name: String)\n\n\nFile(name: String, size: Int)\n\n\nLink(name: String, target: String)\n\n\nSynonyms:\nftpasta.Listing\nftpasta Listing","url":"ftpasta.html#Listing"},{"doc":"ftpasta","title":"append_bytes","content":"pub fn append_bytes(\n  connection: Connection,\n  data: BitArray,\n  remote_file: String,\n) -&gt; Result(Nil, FTPError)\n Append some data onto a file on the server.\nSynonyms:\nftpasta.append_bytes\nftpasta append_bytes","url":"ftpasta.html#append_bytes"},{"doc":"ftpasta","title":"append_file","content":"pub fn append_file(\n  connection: Connection,\n  local_file: String,\n  remote_file: String,\n) -&gt; Result(Nil, FTPError)\n Append a file to another file on the server.\nSynonyms:\nftpasta.append_file\nftpasta append_file","url":"ftpasta.html#append_file"},{"doc":"ftpasta","title":"auth","content":"pub fn auth(\n  config: Config,\n  username: String,\n  password: String,\n) -&gt; Config\n Provide a username and password.\nSynonyms:\nftpasta.auth\nftpasta auth","url":"ftpasta.html#auth"},{"doc":"ftpasta","title":"change_working_dir","content":"pub fn change_working_dir(\n  connection: Connection,\n  remote_dir: String,\n) -&gt; Result(Nil, FTPError)\n Change directories on the remote server.\nSynonyms:\nftpasta.change_working_dir\nftpasta change_working_dir","url":"ftpasta.html#change_working_dir"},{"doc":"ftpasta","title":"close","content":"pub fn close(connection: Connection) -&gt; Nil\n Close the connection.\nSynonyms:\nftpasta.close\nftpasta close","url":"ftpasta.html#close"},{"doc":"ftpasta","title":"connect","content":"pub fn connect(config: Config) -&gt; Result(Connection, FTPError)\n Connect to the server.\nSynonyms:\nftpasta.connect\nftpasta connect","url":"ftpasta.html#connect"},{"doc":"ftpasta","title":"create_dir","content":"pub fn create_dir(\n  connection: Connection,\n  remote_dir: String,\n) -&gt; Result(Nil, FTPError)\n Create a new directory on the server.\nSynonyms:\nftpasta.create_dir\nftpasta create_dir","url":"ftpasta.html#create_dir"},{"doc":"ftpasta","title":"delete_dir","content":"pub fn delete_dir(\n  connection: Connection,\n  remote_dir: String,\n) -&gt; Result(Nil, FTPError)\n Remove an empty directory from the server.\nSynonyms:\nftpasta.delete_dir\nftpasta delete_dir","url":"ftpasta.html#delete_dir"},{"doc":"ftpasta","title":"delete_file","content":"pub fn delete_file(\n  connection: Connection,\n  remote_file: String,\n) -&gt; Result(Nil, FTPError)\n Remove a file from the server.\nSynonyms:\nftpasta.delete_file\nftpasta delete_file","url":"ftpasta.html#delete_file"},{"doc":"ftpasta","title":"delete_recursive","content":"pub fn delete_recursive(\n  connection: Connection,\n  remote_dir: String,\n) -&gt; Result(Nil, FTPError)\n Remove a directory and all contents from the server.\nSynonyms:\nftpasta.delete_recursive\nftpasta delete_recursive","url":"ftpasta.html#delete_recursive"},{"doc":"ftpasta","title":"describe_error","content":"pub fn describe_error(error: FTPError) -&gt; String\n Convert an FTPError into a descriptive string.\nSynonyms:\nftpasta.describe_error\nftpasta describe_error","url":"ftpasta.html#describe_error"},{"doc":"ftpasta","title":"download_bytes","content":"pub fn download_bytes(\n  connection: Connection,\n  remote_file: String,\n) -&gt; Result(BitArray, FTPError)\n Fetch a file from the server, and return it as a BitArray.\nSynonyms:\nftpasta.download_bytes\nftpasta download_bytes","url":"ftpasta.html#download_bytes"},{"doc":"ftpasta","title":"download_file","content":"pub fn download_file(\n  connection: Connection,\n  remote_file: String,\n  local_file: String,\n) -&gt; Result(Nil, FTPError)\n Fetch a file from the server.\nSynonyms:\nftpasta.download_file\nftpasta download_file","url":"ftpasta.html#download_file"},{"doc":"ftpasta","title":"download_recursive","content":"pub fn download_recursive(\n  connection: Connection,\n  remote_dir: String,\n  local_dir: String,\n) -&gt; Result(Nil, FTPError)\n Fetch a directory and all contents recursively from the server.\nSynonyms:\nftpasta.download_recursive\nftpasta download_recursive","url":"ftpasta.html#download_recursive"},{"doc":"ftpasta","title":"encryption","content":"pub fn encryption(config: Config, tls: TLSConfig) -&gt; Config\n Use encryption.\nSynonyms:\nftpasta.encryption\nftpasta encryption","url":"ftpasta.html#encryption"},{"doc":"ftpasta","title":"get_working_dir","content":"pub fn get_working_dir(\n  connection: Connection,\n) -&gt; Result(String, FTPError)\n Get the current remote path used for the connection.\nSynonyms:\nftpasta.get_working_dir\nftpasta get_working_dir","url":"ftpasta.html#get_working_dir"},{"doc":"ftpasta","title":"list","content":"pub fn list(\n  connection: Connection,\n  remote_dir: String,\n) -&gt; Result(List(Listing), FTPError)\n List all files, symlinks, and subdirectories in a directory.\nSynonyms:\nftpasta.list\nftpasta list","url":"ftpasta.html#list"},{"doc":"ftpasta","title":"new","content":"pub fn new(host: String) -&gt; Config\n Start building an FTP connection.\nSynonyms:\nftpasta.new\nftpasta new","url":"ftpasta.html#new"},{"doc":"ftpasta","title":"port","content":"pub fn port(config: Config, port: Int) -&gt; Config\n Use a non-default port.\nSynonyms:\nftpasta.port\nftpasta port","url":"ftpasta.html#port"},{"doc":"ftpasta","title":"rename","content":"pub fn rename(\n  connection: Connection,\n  old_path: String,\n  new_path: String,\n) -&gt; Result(Nil, FTPError)\n Rename a file or directory on the server.\nSynonyms:\nftpasta.rename\nftpasta rename","url":"ftpasta.html#rename"},{"doc":"ftpasta","title":"upload_bytes","content":"pub fn upload_bytes(\n  connection: Connection,\n  data: BitArray,\n  remote_file: String,\n) -&gt; Result(Nil, FTPError)\n Send a data in memory to the server.\nSynonyms:\nftpasta.upload_bytes\nftpasta upload_bytes","url":"ftpasta.html#upload_bytes"},{"doc":"ftpasta","title":"upload_file","content":"pub fn upload_file(\n  connection: Connection,\n  local_file: String,\n  remote_file: String,\n) -&gt; Result(Nil, FTPError)\n Send a file to the server.\nSynonyms:\nftpasta.upload_file\nftpasta upload_file","url":"ftpasta.html#upload_file"},{"doc":"ftpasta","title":"upload_recursive","content":"pub fn upload_recursive(\n  connection: Connection,\n  local_dir: String,\n  remote_dir: String,\n) -&gt; Result(Nil, FTPError)\n Send a directory and all contents to the server.\nSynonyms:\nftpasta.upload_recursive\nftpasta upload_recursive","url":"ftpasta.html#upload_recursive"},{"doc":"ftpasta","title":"ftpasta","content":"","url":"ftpasta.html"}]);